@@ -26,6 +26,7 @@ class permission_manager {
         'service-management' => array('root'), // Only root
         'email-management' => array('all'), // All authenticated users (with domain ownership restrictions)
         'backups' => array('all'), // All authenticated users (with backup ownership restrictions)
+        'cpanel-import' => array('all'), // All authenticated users (can import their own backups)
     );
     
     // Define API permissions
@@ -42,6 +43,7 @@ class permission_manager {
         'server-settings' => array('root'),
         'email-management' => array('all'), // All authenticated users (with domain ownership restrictions)
         'backup-actions' => array('all'), // All authenticated users (with backup ownership restrictions)
+        'cpanel-import' => array('all'), // All authenticated users (can import their own backups)
     );
     
     public function __construct() {
@@ -369,13 +371,13 @@ class permission_manager {
         $page_names = array(
             'user-management' => 'User Management',
             'security-management' => 'Security Management',
-    
             'announcements-management' => 'Announcements Management',
             'update-management' => 'Update Management',
             'docker-management' => 'Docker Management',
             'user-resources' => 'User Resources',
             'domains' => 'Domains',
-            'server-settings' => 'Server Settings'
+            'server-settings' => 'Server Settings',
+            'cpanel-import' => 'cPanel Import'
         );
         
         $page_name = isset($page_names[$page]) ? $page_names[$page] : $page;
