@@ -296,7 +296,12 @@ $stats = [
             <div class="card">
                 <div class="card-header">
                     <div class="d-flex justify-content-between align-items-center">
-                        <h5><i class="fa fa-clock-o"></i> Scheduled Backups</h5>
+                        <div>
+                            <h5><i class="fa fa-clock-o"></i> Scheduled Backups</h5>
+                            <small class="text-muted">
+                                <i class="fa fa-info-circle"></i> Next run times shown in your local timezone
+                            </small>
+                        </div>
                         <div>
                             <?php if ($isRoot): ?>
                             <button class="btn btn-outline-info btn-sm me-2" onclick="runSchedulerNow()">
@@ -349,7 +354,15 @@ $stats = [
                                         echo $scheduleText . ' at ' . date('H:i', strtotime($schedule['schedule_time']));
                                         ?>
                                     </td>
-                                    <td><?php echo $schedule['next_run_at'] ? date('Y-m-d H:i', strtotime($schedule['next_run_at'])) : 'N/A'; ?></td>
+                                    <td>
+                                        <?php if ($schedule['next_run_at']): ?>
+                                        <span class="local-time" data-utc="<?php echo date('c', strtotime($schedule['next_run_at'])); ?>">
+                                            <?php echo date('Y-m-d H:i', strtotime($schedule['next_run_at'])); ?>
+                                        </span>
+                                        <?php else: ?>
+                                        N/A
+                                        <?php endif; ?>
+                                    </td>
                                     <td>
                                         <span class="badge bg-<?php echo $schedule['is_active'] ? 'success' : 'secondary'; ?>">
                                             <?php echo $schedule['is_active'] ? 'Active' : 'Inactive'; ?>
@@ -383,7 +396,12 @@ $stats = [
         <div class="col-12">
             <div class="card">
                 <div class="card-header">
-                    <h5><i class="fa fa-history"></i> Recent Backups</h5>
+                    <div class="d-flex justify-content-between align-items-center">
+                        <h5><i class="fa fa-history"></i> Recent Backups</h5>
+                        <small class="text-muted">
+                            <i class="fa fa-clock-o"></i> Times shown in your local timezone
+                        </small>
+                    </div>
                 </div>
                 <div class="card-body">
                     <div class="table-responsive">
@@ -417,7 +435,11 @@ $stats = [
                                             <?php echo ucfirst($backup['status']); ?>
                                         </span>
                                     </td>
-                                    <td><?php echo date('Y-m-d H:i:s', strtotime($backup['started_at'])); ?></td>
+                                    <td>
+                                        <span class="local-time" data-utc="<?php echo date('c', strtotime($backup['started_at'])); ?>">
+                                            <?php echo date('Y-m-d H:i:s', strtotime($backup['started_at'])); ?>
+                                        </span>
+                                    </td>
                                     <td>
                                         <?php if ($backup['status'] === 'completed'): ?>
                                         <button class="btn btn-sm btn-outline-success" onclick="downloadBackup(<?php echo $backup['id']; ?>)">
@@ -1064,6 +1086,41 @@ function showAlert(message, type) {
         alertDiv.remove();
     }, 5000);
 }
+
+// Convert UTC times to local timezone
+function convertToLocalTime() {
+    document.querySelectorAll('.local-time').forEach(element => {
+        const utcTime = element.getAttribute('data-utc');
+        if (utcTime && !element.getAttribute('data-converted')) {
+            try {
+                // Store original server time for tooltip
+                const originalText = element.textContent.trim();
+                
+                const date = new Date(utcTime);
+                const hasSeconds = originalText.includes(':') && originalText.split(':').length > 2;
+                
+                const localTime = date.toLocaleString(undefined, {
+                    year: 'numeric',
+                    month: '2-digit',
+                    day: '2-digit',
+                    hour: '2-digit',
+                    minute: '2-digit',
+                    second: hasSeconds ? '2-digit' : undefined,
+                    hour12: false
+                });
+                
+                element.textContent = localTime;
+                element.title = `Server time: ${originalText}`;
+                element.setAttribute('data-converted', 'true');
+            } catch (error) {
+                console.warn('Failed to convert time:', utcTime, error);
+            }
+        }
+    });
+}
+
+// Convert times when page loads
+document.addEventListener('DOMContentLoaded', convertToLocalTime);
 </script>
 
 <?php
